@@ -944,7 +944,7 @@ function print_output (stats, nboot, alpha, l, m, bootfun_str, strata)
     fprintf (cat (2, ' original     bias         std_error    CI_lower', ...
                      '     CI_upper  \n'));
     for i = 1 : m
-      fprintf (cat (2, ' %#-+10.4g   %#-+10.4g   %#-+10.4g   %#-+10.4g', ...
+      fprintf (cat (2, ' %#-+10.4g   %#-+10.4g   %#-10.4g   %#-+10.4g', ...
                      '   %#-+10.4g \n'), [stats.original(i), stats.bias(i), ...
                      stats.std_error(i), stats.CI_lower(i), stats.CI_upper(i)]);
     end
